#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Project      : MeUtils.
# @File         : sys_monitor
# @Time         : 2022/9/23 下午1:44
# @Author       : yuanjie
# @WeChat       : meutils
# @Software     : PyCharm
# @Description  :
"""
psutil.cpu_count()
psutil.cpu_percent()
psutil.cpu_stats()
psutil.disk_io_counters()

psutil.process_iter()

psutil.swap_memory
psutil.virtual_memory()

"""

import psutil


psutil.test()